==> geopsypack-src-3.3.6.tar.gz: geopsypack-src-3.3.6/ArrayCore/src/ArrayCrossSpectrum.h <==
/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2019-12-02
**  Copyright: 2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef ARRAYCROSSSPECTRUM_H
#define ARRAYCROSSSPECTRUM_H

#include "ArrayCoreDLLExport.h"
#include "ArrayTimeWindows.h"

namespace ArrayCore {

  class ARRAYCORE_EXPORT ArrayCrossSpectrum
  {
  public:
    ArrayCrossSpectrum(const ArraySelection * array,
                       const ArrayParameters * param);
    virtual ~ArrayCrossSpectrum();

    void setTimeWindows(const ArrayTimeWindows * tw) {_timeWindows=tw;}
    const ArrayTimeWindows * timeWindows() const {return _timeWindows;}

    const ArrayParameters * parameters() const {return _parameters;}
    int stationCount() const {return _stations.count();}
    ArrayStations::Mode mode() const {return _mode;}

    void resetRayleigh();
    void resetLove();

    void addVertical();
    void addHorizontalRayleigh() {addHorizontal(_rayleigh);}
    void addHorizontalLove() {addHorizontal(_love);}

    void meanRayleigh(int nBlocks);
    void meanLove(int nBlocks);

    inline const ComplexMatrix& rayleigh() const;
    inline const ComplexMatrix& love() const;

    bool lockTimeWindow(const TimeRange& win, const FourierPlan& plan);
    void unlockTimeWindow();
  protected:
    void addHorizontal(ComplexMatrix& covmat);
    void setStations(const ArraySelection * array);

    QList<ArrayStationSignals *> _stations;
    const ArrayTimeWindows * _timeWindows;
    const ArrayParameters * _parameters;
    ArrayStations::Mode _mode;
    int _verticalIndex, _northIndex, _eastIndex;
    bool _singleValueSpectrum;

    ComplexMatrix _rayleigh;
    ComplexMatrix _love;
  };

  inline const ComplexMatrix& ArrayCrossSpectrum::rayleigh() const
  {
    return _rayleigh;
  }

  inline const ComplexMatrix& ArrayCrossSpectrum::love() const
  {
    return _love;
  }

} // namespace ArrayCore

#endif // ARRAYCROSSSPECTRUM_H

==> geopsypack-src-3.4.0.tar.gz: geopsypack-src-3.4.0/ArrayCore/src/ArrayCrossSpectrum.h <==
/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2019-12-02
**  Copyright: 2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef ARRAYCROSSSPECTRUM_H
#define ARRAYCROSSSPECTRUM_H

#include "ArrayCoreDLLExport.h"
#include "ArrayTimeWindows.h"

namespace ArrayCore {

  class ARRAYCORE_EXPORT ArrayCrossSpectrum
  {
  public:
    ArrayCrossSpectrum(const ArraySelection * array,
                       const ArrayParameters * param);
    virtual ~ArrayCrossSpectrum();

    void setTimeWindows(const ArrayTimeWindows * tw) {_timeWindows=tw;}
    const ArrayTimeWindows * timeWindows() const {return _timeWindows;}

    const ArrayParameters * parameters() const {return _parameters;}
    int stationCount() const {return _stations.count();}
    ArrayStations::Mode mode() const {return _mode;}
    bool isSingleValueSpectrum() const {return _singleValueSpectrum;}

    void resetMatrix();
    void addVertical();
    void addHorizontal() {addHorizontal(_matrix);}
    void meanMatrix(int nBlocks);

    inline const ComplexMatrix& matrix() const {return _matrix;}

    bool lockTimeWindow(const TimeRange& win);
    void unlockTimeWindow();
  protected:
    void addHorizontal(ComplexMatrix& covmat);
    void setStations(const ArraySelection * array);

    QList<ArrayStationSignals *> _stations;
    const ArrayTimeWindows * _timeWindows;
    const ArrayParameters * _parameters;
    ArrayStations::Mode _mode;
    int _verticalIndex, _northIndex, _eastIndex;
    bool _singleValueSpectrum;

    ComplexMatrix _matrix;
  };

} // namespace ArrayCore

#endif // ARRAYCROSSSPECTRUM_H
